@@ -38,9 +38,6 @@ CliInterface::CliInterface(QObject *parent, const QVariantList &args)
     // because this interface uses the event loop
     setWaitForFinishedSignal(true);
 
-    if (QMetaType::type("QProcess::ExitStatus") == 0) {
-        qRegisterMetaType<QProcess::ExitStatus>("QProcess::ExitStatus");
-    }
     m_cliProps = new CliProperties(this, m_metaData, mimetype());
 }
 
@@ -251,7 +248,7 @@ bool CliInterface::runProcess(const QString &programName, const QStringList &arg
     m_process->setNextOpenMode(QIODevice::ReadWrite | QIODevice::Unbuffered | QIODevice::Text);
     m_process->setProgram(programPath, arguments);
 
-    m_readyStdOutConnection = connect(m_process, &QProcess::readyReadStandardOutput, this, [=]() {
+    m_readyStdOutConnection = connect(m_process, &QProcess::readyReadStandardOutput, this, [this]() {
         readStdout();
     });
 
